@@ -20,20 +20,26 @@ from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .literals import (
+    FileTypeType,
     ReadSetFileType,
+    ReadSetPartSourceType,
     ReferenceFileType,
     RunLogLevelType,
+    RunStatusType,
     StoreFormatType,
     TaskStatusType,
     WorkflowEngineType,
+    WorkflowTypeType,
 )
 from .paginator import (
     ListAnnotationImportJobsPaginator,
     ListAnnotationStoresPaginator,
+    ListMultipartReadSetUploadsPaginator,
     ListReadSetActivationJobsPaginator,
     ListReadSetExportJobsPaginator,
     ListReadSetImportJobsPaginator,
     ListReadSetsPaginator,
+    ListReadSetUploadPartsPaginator,
     ListReferenceImportJobsPaginator,
     ListReferencesPaginator,
     ListReferenceStoresPaginator,
@@ -49,7 +55,10 @@ from .type_defs import (
     ActivateReadSetFilterTypeDef,
     AnnotationImportItemSourceTypeDef,
     BatchDeleteReadSetResponseTypeDef,
+    CompleteMultipartReadSetUploadResponseTypeDef,
+    CompleteReadSetUploadPartListItemTypeDef,
     CreateAnnotationStoreResponseTypeDef,
+    CreateMultipartReadSetUploadResponseTypeDef,
     CreateReferenceStoreResponseTypeDef,
     CreateRunGroupResponseTypeDef,
     CreateSequenceStoreResponseTypeDef,
@@ -85,10 +94,12 @@ from .type_defs import (
     ListAnnotationImportJobsResponseTypeDef,
     ListAnnotationStoresFilterTypeDef,
     ListAnnotationStoresResponseTypeDef,
+    ListMultipartReadSetUploadsResponseTypeDef,
     ListReadSetActivationJobsResponseTypeDef,
     ListReadSetExportJobsResponseTypeDef,
     ListReadSetImportJobsResponseTypeDef,
     ListReadSetsResponseTypeDef,
+    ListReadSetUploadPartsResponseTypeDef,
     ListReferenceImportJobsResponseTypeDef,
     ListReferencesResponseTypeDef,
     ListReferenceStoresResponseTypeDef,
@@ -103,6 +114,7 @@ from .type_defs import (
     ListVariantStoresResponseTypeDef,
     ListWorkflowsResponseTypeDef,
     ReadSetFilterTypeDef,
+    ReadSetUploadPartListFilterTypeDef,
     ReferenceFilterTypeDef,
     ReferenceItemTypeDef,
     ReferenceStoreFilterTypeDef,
@@ -118,9 +130,11 @@ from .type_defs import (
     StartReferenceImportJobSourceItemTypeDef,
     StartRunResponseTypeDef,
     StartVariantImportResponseTypeDef,
+    StoreOptionsOutputTypeDef,
     StoreOptionsTypeDef,
     UpdateAnnotationStoreResponseTypeDef,
     UpdateVariantStoreResponseTypeDef,
+    UploadReadSetPartResponseTypeDef,
     VariantImportItemSourceTypeDef,
     WorkflowParameterTypeDef,
 )
@@ -164,6 +178,7 @@ class Exceptions:
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
+    NotSupportedOperationException: Type[BotocoreClientError]
     RangeNotSatisfiableException: Type[BotocoreClientError]
     RequestTimeoutException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
@@ -189,6 +204,16 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#exceptions)
         """
 
+    def abort_multipart_read_set_upload(
+        self, *, sequenceStoreId: str, uploadId: str
+    ) -> Dict[str, Any]:
+        """
+        Stops a multipart upload.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.abort_multipart_read_set_upload)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#abort_multipart_read_set_upload)
+        """
+
     def batch_delete_read_set(
         self, *, ids: Sequence[str], sequenceStoreId: str
     ) -> BatchDeleteReadSetResponseTypeDef:
@@ -239,16 +264,30 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#close)
         """
 
+    def complete_multipart_read_set_upload(
+        self,
+        *,
+        sequenceStoreId: str,
+        uploadId: str,
+        parts: Sequence[CompleteReadSetUploadPartListItemTypeDef]
+    ) -> CompleteMultipartReadSetUploadResponseTypeDef:
+        """
+        Concludes a multipart upload once you have uploaded all the components.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.complete_multipart_read_set_upload)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#complete_multipart_read_set_upload)
+        """
+
     def create_annotation_store(
         self,
         *,
         storeFormat: StoreFormatType,
-        description: str = ...,
-        name: str = ...,
         reference: ReferenceItemTypeDef = ...,
+        name: str = ...,
+        description: str = ...,
+        tags: Mapping[str, str] = ...,
         sseConfig: SseConfigTypeDef = ...,
-        storeOptions: StoreOptionsTypeDef = ...,
-        tags: Mapping[str, str] = ...
+        storeOptions: Union[StoreOptionsTypeDef, StoreOptionsOutputTypeDef] = ...
     ) -> CreateAnnotationStoreResponseTypeDef:
         """
         Creates an annotation store.
@@ -257,14 +296,35 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#create_annotation_store)
         """
 
+    def create_multipart_read_set_upload(
+        self,
+        *,
+        sequenceStoreId: str,
+        sourceFileType: FileTypeType,
+        subjectId: str,
+        sampleId: str,
+        referenceArn: str,
+        name: str,
+        clientToken: str = ...,
+        generatedFrom: str = ...,
+        description: str = ...,
+        tags: Mapping[str, str] = ...
+    ) -> CreateMultipartReadSetUploadResponseTypeDef:
+        """
+        Begins a multipart read set upload.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.create_multipart_read_set_upload)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#create_multipart_read_set_upload)
+        """
+
     def create_reference_store(
         self,
         *,
         name: str,
-        clientToken: str = ...,
         description: str = ...,
         sseConfig: SseConfigTypeDef = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        clientToken: str = ...
     ) -> CreateReferenceStoreResponseTypeDef:
         """
         Creates a reference store.
@@ -277,11 +337,12 @@ class OmicsClient(BaseClient):
         self,
         *,
         requestId: str,
-        maxCpus: int = ...,
-        maxDuration: int = ...,
-        maxRuns: int = ...,
         name: str = ...,
-        tags: Mapping[str, str] = ...
+        maxCpus: int = ...,
+        maxRuns: int = ...,
+        maxDuration: int = ...,
+        tags: Mapping[str, str] = ...,
+        maxGpus: int = ...
     ) -> CreateRunGroupResponseTypeDef:
         """
         Creates a run group.
@@ -294,10 +355,11 @@ class OmicsClient(BaseClient):
         self,
         *,
         name: str,
-        clientToken: str = ...,
         description: str = ...,
         sseConfig: SseConfigTypeDef = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        clientToken: str = ...,
+        fallbackLocation: str = ...
     ) -> CreateSequenceStoreResponseTypeDef:
         """
         Creates a sequence store.
@@ -310,10 +372,10 @@ class OmicsClient(BaseClient):
         self,
         *,
         reference: ReferenceItemTypeDef,
-        description: str = ...,
         name: str = ...,
-        sseConfig: SseConfigTypeDef = ...,
-        tags: Mapping[str, str] = ...
+        description: str = ...,
+        tags: Mapping[str, str] = ...,
+        sseConfig: SseConfigTypeDef = ...
     ) -> CreateVariantStoreResponseTypeDef:
         """
         Creates a variant store.
@@ -326,15 +388,16 @@ class OmicsClient(BaseClient):
         self,
         *,
         requestId: str,
-        definitionUri: str = ...,
-        definitionZip: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        name: str = ...,
         description: str = ...,
         engine: WorkflowEngineType = ...,
+        definitionZip: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        definitionUri: str = ...,
         main: str = ...,
-        name: str = ...,
         parameterTemplate: Mapping[str, WorkflowParameterTypeDef] = ...,
         storageCapacity: int = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        accelerators: Literal["GPU"] = ...
     ) -> CreateWorkflowResponseTypeDef:
         """
         Creates a workflow.
@@ -442,7 +505,7 @@ class OmicsClient(BaseClient):
         """
 
     def get_read_set(
-        self, *, id: str, partNumber: int, sequenceStoreId: str, file: ReadSetFileType = ...
+        self, *, id: str, sequenceStoreId: str, partNumber: int, file: ReadSetFileType = ...
     ) -> GetReadSetResponseTypeDef:
         """
         Gets a file from a read set.
@@ -462,7 +525,7 @@ class OmicsClient(BaseClient):
         """
 
     def get_read_set_export_job(
-        self, *, id: str, sequenceStoreId: str
+        self, *, sequenceStoreId: str, id: str
     ) -> GetReadSetExportJobResponseTypeDef:
         """
         Gets information about a read set export job.
@@ -495,10 +558,10 @@ class OmicsClient(BaseClient):
         self,
         *,
         id: str,
-        partNumber: int,
         referenceStoreId: str,
-        file: ReferenceFileType = ...,
-        range: str = ...
+        partNumber: int,
+        range: str = ...,
+        file: ReferenceFileType = ...
     ) -> GetReferenceResponseTypeDef:
         """
         Gets a reference file.
@@ -589,8 +652,8 @@ class OmicsClient(BaseClient):
         self,
         *,
         id: str,
-        export: Sequence[Literal["DEFINITION"]] = ...,
-        type: Literal["PRIVATE"] = ...
+        type: WorkflowTypeType = ...,
+        export: Sequence[Literal["DEFINITION"]] = ...
     ) -> GetWorkflowResponseTypeDef:
         """
         Gets information about a workflow.
@@ -602,10 +665,10 @@ class OmicsClient(BaseClient):
     def list_annotation_import_jobs(
         self,
         *,
-        filter: ListAnnotationImportJobsFilterTypeDef = ...,
-        ids: Sequence[str] = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        ids: Sequence[str] = ...,
+        nextToken: str = ...,
+        filter: ListAnnotationImportJobsFilterTypeDef = ...
     ) -> ListAnnotationImportJobsResponseTypeDef:
         """
         Retrieves a list of annotation import jobs.
@@ -617,10 +680,10 @@ class OmicsClient(BaseClient):
     def list_annotation_stores(
         self,
         *,
-        filter: ListAnnotationStoresFilterTypeDef = ...,
         ids: Sequence[str] = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ListAnnotationStoresFilterTypeDef = ...
     ) -> ListAnnotationStoresResponseTypeDef:
         """
         Retrieves a list of annotation stores.
@@ -629,13 +692,23 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#list_annotation_stores)
         """
 
+    def list_multipart_read_set_uploads(
+        self, *, sequenceStoreId: str, maxResults: int = ..., nextToken: str = ...
+    ) -> ListMultipartReadSetUploadsResponseTypeDef:
+        """
+        Lists all multipart read set uploads and their statuses.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.list_multipart_read_set_uploads)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#list_multipart_read_set_uploads)
+        """
+
     def list_read_set_activation_jobs(
         self,
         *,
         sequenceStoreId: str,
-        filter: ActivateReadSetFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ActivateReadSetFilterTypeDef = ...
     ) -> ListReadSetActivationJobsResponseTypeDef:
         """
         Retrieves a list of read set activation jobs.
@@ -648,9 +721,9 @@ class OmicsClient(BaseClient):
         self,
         *,
         sequenceStoreId: str,
-        filter: ExportReadSetFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ExportReadSetFilterTypeDef = ...
     ) -> ListReadSetExportJobsResponseTypeDef:
         """
         Retrieves a list of read set export jobs.
@@ -663,9 +736,9 @@ class OmicsClient(BaseClient):
         self,
         *,
         sequenceStoreId: str,
-        filter: ImportReadSetFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ImportReadSetFilterTypeDef = ...
     ) -> ListReadSetImportJobsResponseTypeDef:
         """
         Retrieves a list of read set import jobs.
@@ -674,13 +747,31 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#list_read_set_import_jobs)
         """
 
+    def list_read_set_upload_parts(
+        self,
+        *,
+        sequenceStoreId: str,
+        uploadId: str,
+        partSource: ReadSetPartSourceType,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        filter: ReadSetUploadPartListFilterTypeDef = ...
+    ) -> ListReadSetUploadPartsResponseTypeDef:
+        """
+        This operation will list all parts in a requested multipart upload for a
+        sequence store.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.list_read_set_upload_parts)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#list_read_set_upload_parts)
+        """
+
     def list_read_sets(
         self,
         *,
         sequenceStoreId: str,
-        filter: ReadSetFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ReadSetFilterTypeDef = ...
     ) -> ListReadSetsResponseTypeDef:
         """
         Retrieves a list of read sets.
@@ -693,9 +784,9 @@ class OmicsClient(BaseClient):
         self,
         *,
         referenceStoreId: str,
-        filter: ImportReferenceFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ImportReferenceFilterTypeDef = ...
     ) -> ListReferenceImportJobsResponseTypeDef:
         """
         Retrieves a list of reference import jobs.
@@ -707,9 +798,9 @@ class OmicsClient(BaseClient):
     def list_reference_stores(
         self,
         *,
-        filter: ReferenceStoreFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ReferenceStoreFilterTypeDef = ...
     ) -> ListReferenceStoresResponseTypeDef:
         """
         Retrieves a list of reference stores.
@@ -722,9 +813,9 @@ class OmicsClient(BaseClient):
         self,
         *,
         referenceStoreId: str,
-        filter: ReferenceFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: ReferenceFilterTypeDef = ...
     ) -> ListReferencesResponseTypeDef:
         """
         Retrieves a list of references.
@@ -734,7 +825,7 @@ class OmicsClient(BaseClient):
         """
 
     def list_run_groups(
-        self, *, maxResults: int = ..., name: str = ..., startingToken: str = ...
+        self, *, name: str = ..., startingToken: str = ..., maxResults: int = ...
     ) -> ListRunGroupsResponseTypeDef:
         """
         Retrieves a list of run groups.
@@ -747,9 +838,9 @@ class OmicsClient(BaseClient):
         self,
         *,
         id: str,
-        maxResults: int = ...,
+        status: TaskStatusType = ...,
         startingToken: str = ...,
-        status: TaskStatusType = ...
+        maxResults: int = ...
     ) -> ListRunTasksResponseTypeDef:
         """
         Retrieves a list of tasks for a run.
@@ -761,10 +852,11 @@ class OmicsClient(BaseClient):
     def list_runs(
         self,
         *,
-        maxResults: int = ...,
         name: str = ...,
         runGroupId: str = ...,
-        startingToken: str = ...
+        startingToken: str = ...,
+        maxResults: int = ...,
+        status: RunStatusType = ...
     ) -> ListRunsResponseTypeDef:
         """
         Retrieves a list of runs.
@@ -776,9 +868,9 @@ class OmicsClient(BaseClient):
     def list_sequence_stores(
         self,
         *,
-        filter: SequenceStoreFilterTypeDef = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        filter: SequenceStoreFilterTypeDef = ...
     ) -> ListSequenceStoresResponseTypeDef:
         """
         Retrieves a list of sequence stores.
@@ -798,10 +890,10 @@ class OmicsClient(BaseClient):
     def list_variant_import_jobs(
         self,
         *,
-        filter: ListVariantImportJobsFilterTypeDef = ...,
-        ids: Sequence[str] = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        ids: Sequence[str] = ...,
+        nextToken: str = ...,
+        filter: ListVariantImportJobsFilterTypeDef = ...
     ) -> ListVariantImportJobsResponseTypeDef:
         """
         Retrieves a list of variant import jobs.
@@ -813,10 +905,10 @@ class OmicsClient(BaseClient):
     def list_variant_stores(
         self,
         *,
-        filter: ListVariantStoresFilterTypeDef = ...,
-        ids: Sequence[str] = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        ids: Sequence[str] = ...,
+        nextToken: str = ...,
+        filter: ListVariantStoresFilterTypeDef = ...
     ) -> ListVariantStoresResponseTypeDef:
         """
         Retrieves a list of variant stores.
@@ -828,10 +920,10 @@ class OmicsClient(BaseClient):
     def list_workflows(
         self,
         *,
-        maxResults: int = ...,
+        type: WorkflowTypeType = ...,
         name: str = ...,
         startingToken: str = ...,
-        type: Literal["PRIVATE"] = ...
+        maxResults: int = ...
     ) -> ListWorkflowsResponseTypeDef:
         """
         Retrieves a list of workflows.
@@ -844,10 +936,11 @@ class OmicsClient(BaseClient):
         self,
         *,
         destinationName: str,
-        items: Sequence[AnnotationImportItemSourceTypeDef],
         roleArn: str,
+        items: Sequence[AnnotationImportItemSourceTypeDef],
         formatOptions: FormatOptionsTypeDef = ...,
-        runLeftNormalization: bool = ...
+        runLeftNormalization: bool = ...,
+        annotationFields: Mapping[str, str] = ...
     ) -> StartAnnotationImportResponseTypeDef:
         """
         Starts an annotation import job.
@@ -873,9 +966,9 @@ class OmicsClient(BaseClient):
     def start_read_set_export_job(
         self,
         *,
+        sequenceStoreId: str,
         destination: str,
         roleArn: str,
-        sequenceStoreId: str,
         sources: Sequence[ExportReadSetTypeDef],
         clientToken: str = ...
     ) -> StartReadSetExportJobResponseTypeDef:
@@ -889,8 +982,8 @@ class OmicsClient(BaseClient):
     def start_read_set_import_job(
         self,
         *,
-        roleArn: str,
         sequenceStoreId: str,
+        roleArn: str,
         sources: Sequence[StartReadSetImportJobSourceItemTypeDef],
         clientToken: str = ...
     ) -> StartReadSetImportJobResponseTypeDef:
@@ -919,19 +1012,19 @@ class OmicsClient(BaseClient):
     def start_run(
         self,
         *,
-        requestId: str,
         roleArn: str,
-        logLevel: RunLogLevelType = ...,
-        name: str = ...,
-        outputUri: str = ...,
-        parameters: Mapping[str, Any] = ...,
-        priority: int = ...,
-        runGroupId: str = ...,
-        runId: str = ...,
-        storageCapacity: int = ...,
-        tags: Mapping[str, str] = ...,
+        requestId: str,
         workflowId: str = ...,
-        workflowType: Literal["PRIVATE"] = ...
+        workflowType: WorkflowTypeType = ...,
+        runId: str = ...,
+        name: str = ...,
+        runGroupId: str = ...,
+        priority: int = ...,
+        parameters: Mapping[str, Any] = ...,
+        storageCapacity: int = ...,
+        outputUri: str = ...,
+        logLevel: RunLogLevelType = ...,
+        tags: Mapping[str, str] = ...
     ) -> StartRunResponseTypeDef:
         """
         Starts a run.
@@ -944,9 +1037,10 @@ class OmicsClient(BaseClient):
         self,
         *,
         destinationName: str,
-        items: Sequence[VariantImportItemSourceTypeDef],
         roleArn: str,
-        runLeftNormalization: bool = ...
+        items: Sequence[VariantImportItemSourceTypeDef],
+        runLeftNormalization: bool = ...,
+        annotationFields: Mapping[str, str] = ...
     ) -> StartVariantImportResponseTypeDef:
         """
         Starts a variant import job.
@@ -985,10 +1079,11 @@ class OmicsClient(BaseClient):
         self,
         *,
         id: str,
+        name: str = ...,
         maxCpus: int = ...,
-        maxDuration: int = ...,
         maxRuns: int = ...,
-        name: str = ...
+        maxDuration: int = ...,
+        maxGpus: int = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Updates a run group.
@@ -1008,7 +1103,7 @@ class OmicsClient(BaseClient):
         """
 
     def update_workflow(
-        self, *, id: str, description: str = ..., name: str = ...
+        self, *, id: str, name: str = ..., description: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Updates a workflow.
@@ -1017,6 +1112,22 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#update_workflow)
         """
 
+    def upload_read_set_part(
+        self,
+        *,
+        sequenceStoreId: str,
+        uploadId: str,
+        partSource: ReadSetPartSourceType,
+        partNumber: int,
+        payload: Union[str, bytes, IO[Any], StreamingBody]
+    ) -> UploadReadSetPartResponseTypeDef:
+        """
+        This operation uploads a specific part of a read set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.upload_read_set_part)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#upload_read_set_part)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_annotation_import_jobs"]
@@ -1035,6 +1146,15 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_multipart_read_set_uploads"]
+    ) -> ListMultipartReadSetUploadsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_read_set_activation_jobs"]
@@ -1062,6 +1182,15 @@ class OmicsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_read_set_upload_parts"]
+    ) -> ListReadSetUploadPartsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_read_sets"]) -> ListReadSetsPaginator:
         """
