@@ -6,9 +6,9 @@ Type annotations for omics service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_omics.literals import AnnotationImportJobCreatedWaiterName
+    from mypy_boto3_omics.literals import AcceleratorsType
 
-    data: AnnotationImportJobCreatedWaiterName = "annotation_import_job_created"
+    data: AcceleratorsType = "GPU"
     ```
 """
 import sys
@@ -20,19 +20,23 @@ else:
 
 
 __all__ = (
+    "AcceleratorsType",
     "AnnotationImportJobCreatedWaiterName",
     "AnnotationStoreCreatedWaiterName",
     "AnnotationStoreDeletedWaiterName",
     "AnnotationTypeType",
+    "CreationTypeType",
     "EncryptionTypeType",
     "FileTypeType",
     "FormatToHeaderKeyType",
     "JobStatusType",
     "ListAnnotationImportJobsPaginatorName",
     "ListAnnotationStoresPaginatorName",
+    "ListMultipartReadSetUploadsPaginatorName",
     "ListReadSetActivationJobsPaginatorName",
     "ListReadSetExportJobsPaginatorName",
     "ListReadSetImportJobsPaginatorName",
+    "ListReadSetUploadPartsPaginatorName",
     "ListReadSetsPaginatorName",
     "ListReferenceImportJobsPaginatorName",
     "ListReferenceStoresPaginatorName",
@@ -54,6 +58,7 @@ __all__ = (
     "ReadSetImportJobCompletedWaiterName",
     "ReadSetImportJobItemStatusType",
     "ReadSetImportJobStatusType",
+    "ReadSetPartSourceType",
     "ReadSetStatusType",
     "ReferenceFileType",
     "ReferenceImportJobCompletedWaiterName",
@@ -84,9 +89,11 @@ __all__ = (
     "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
+AcceleratorsType = Literal["GPU"]
 AnnotationImportJobCreatedWaiterName = Literal["annotation_import_job_created"]
 AnnotationStoreCreatedWaiterName = Literal["annotation_store_created"]
 AnnotationStoreDeletedWaiterName = Literal["annotation_store_deleted"]
@@ -99,6 +106,7 @@ AnnotationTypeType = Literal[
     "CHR_START_END_ZERO_BASE",
     "GENERIC",
 ]
+CreationTypeType = Literal["IMPORT", "UPLOAD"]
 EncryptionTypeType = Literal["KMS"]
 FileTypeType = Literal["BAM", "CRAM", "FASTQ"]
 FormatToHeaderKeyType = Literal["ALT", "CHR", "END", "POS", "REF", "START"]
@@ -107,9 +115,11 @@ JobStatusType = Literal[
 ]
 ListAnnotationImportJobsPaginatorName = Literal["list_annotation_import_jobs"]
 ListAnnotationStoresPaginatorName = Literal["list_annotation_stores"]
+ListMultipartReadSetUploadsPaginatorName = Literal["list_multipart_read_set_uploads"]
 ListReadSetActivationJobsPaginatorName = Literal["list_read_set_activation_jobs"]
 ListReadSetExportJobsPaginatorName = Literal["list_read_set_export_jobs"]
 ListReadSetImportJobsPaginatorName = Literal["list_read_set_import_jobs"]
+ListReadSetUploadPartsPaginatorName = Literal["list_read_set_upload_parts"]
 ListReadSetsPaginatorName = Literal["list_read_sets"]
 ListReferenceImportJobsPaginatorName = Literal["list_reference_import_jobs"]
 ListReferenceStoresPaginatorName = Literal["list_reference_stores"]
@@ -155,7 +165,10 @@ ReadSetImportJobStatusType = Literal[
     "IN_PROGRESS",
     "SUBMITTED",
 ]
-ReadSetStatusType = Literal["ACTIVATING", "ACTIVE", "ARCHIVED", "DELETED", "DELETING"]
+ReadSetPartSourceType = Literal["SOURCE1", "SOURCE2"]
+ReadSetStatusType = Literal[
+    "ACTIVATING", "ACTIVE", "ARCHIVED", "DELETED", "DELETING", "PROCESSING_UPLOAD", "UPLOAD_FAILED"
+]
 ReferenceFileType = Literal["INDEX", "SOURCE"]
 ReferenceImportJobCompletedWaiterName = Literal["reference_import_job_completed"]
 ReferenceImportJobItemStatusType = Literal["FAILED", "FINISHED", "IN_PROGRESS", "NOT_STARTED"]
@@ -188,10 +201,10 @@ VariantImportJobCreatedWaiterName = Literal["variant_import_job_created"]
 VariantStoreCreatedWaiterName = Literal["variant_store_created"]
 VariantStoreDeletedWaiterName = Literal["variant_store_deleted"]
 WorkflowActiveWaiterName = Literal["workflow_active"]
-WorkflowEngineType = Literal["NEXTFLOW", "WDL"]
+WorkflowEngineType = Literal["CWL", "NEXTFLOW", "WDL"]
 WorkflowExportType = Literal["DEFINITION"]
-WorkflowStatusType = Literal["ACTIVE", "CREATING", "DELETED", "FAILED", "UPDATING"]
-WorkflowTypeType = Literal["PRIVATE"]
+WorkflowStatusType = Literal["ACTIVE", "CREATING", "DELETED", "FAILED", "INACTIVE", "UPDATING"]
+WorkflowTypeType = Literal["PRIVATE", "READY2RUN"]
 OmicsServiceName = Literal["omics"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -208,6 +221,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -255,6 +269,7 @@ ServiceName = Literal[
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -310,6 +325,7 @@ ServiceName = Literal[
     "emr",
     "emr-containers",
     "emr-serverless",
+    "entityresolution",
     "es",
     "events",
     "evidently",
@@ -396,6 +412,7 @@ ServiceName = Literal[
     "macie",
     "macie2",
     "managedblockchain",
+    "managedblockchain-query",
     "marketplace-catalog",
     "marketplace-entitlement",
     "marketplacecommerceanalytics",
@@ -404,9 +421,11 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
+    "medical-imaging",
     "memorydb",
     "meteringmarketplace",
     "mgh",
@@ -430,8 +449,11 @@ ServiceName = Literal[
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -523,6 +545,7 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "verifiedpermissions",
     "voice-id",
     "vpc-lattice",
     "waf",
@@ -553,9 +576,11 @@ ResourceServiceName = Literal[
 PaginatorName = Literal[
     "list_annotation_import_jobs",
     "list_annotation_stores",
+    "list_multipart_read_set_uploads",
     "list_read_set_activation_jobs",
     "list_read_set_export_jobs",
     "list_read_set_import_jobs",
+    "list_read_set_upload_parts",
     "list_read_sets",
     "list_reference_import_jobs",
     "list_reference_stores",
@@ -585,3 +610,6 @@ WaiterName = Literal[
     "variant_store_deleted",
     "workflow_active",
 ]
+RegionName = Literal[
+    "ap-southeast-1", "eu-central-1", "eu-west-1", "eu-west-2", "us-east-1", "us-west-2"
+]
