@@ -12,9 +12,11 @@ Usage::
     from mypy_boto3_omics.paginator import (
         ListAnnotationImportJobsPaginator,
         ListAnnotationStoresPaginator,
+        ListMultipartReadSetUploadsPaginator,
         ListReadSetActivationJobsPaginator,
         ListReadSetExportJobsPaginator,
         ListReadSetImportJobsPaginator,
+        ListReadSetUploadPartsPaginator,
         ListReadSetsPaginator,
         ListReferenceImportJobsPaginator,
         ListReferenceStoresPaginator,
@@ -33,9 +35,11 @@ Usage::
 
     list_annotation_import_jobs_paginator: ListAnnotationImportJobsPaginator = client.get_paginator("list_annotation_import_jobs")
     list_annotation_stores_paginator: ListAnnotationStoresPaginator = client.get_paginator("list_annotation_stores")
+    list_multipart_read_set_uploads_paginator: ListMultipartReadSetUploadsPaginator = client.get_paginator("list_multipart_read_set_uploads")
     list_read_set_activation_jobs_paginator: ListReadSetActivationJobsPaginator = client.get_paginator("list_read_set_activation_jobs")
     list_read_set_export_jobs_paginator: ListReadSetExportJobsPaginator = client.get_paginator("list_read_set_export_jobs")
     list_read_set_import_jobs_paginator: ListReadSetImportJobsPaginator = client.get_paginator("list_read_set_import_jobs")
+    list_read_set_upload_parts_paginator: ListReadSetUploadPartsPaginator = client.get_paginator("list_read_set_upload_parts")
     list_read_sets_paginator: ListReadSetsPaginator = client.get_paginator("list_read_sets")
     list_reference_import_jobs_paginator: ListReferenceImportJobsPaginator = client.get_paginator("list_reference_import_jobs")
     list_reference_stores_paginator: ListReferenceStoresPaginator = client.get_paginator("list_reference_stores")
@@ -49,12 +53,11 @@ Usage::
     list_workflows_paginator: ListWorkflowsPaginator = client.get_paginator("list_workflows")
     ```
 """
-import sys
 from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
 
-from .literals import TaskStatusType
+from .literals import ReadSetPartSourceType, RunStatusType, TaskStatusType, WorkflowTypeType
 from .type_defs import (
     ActivateReadSetFilterTypeDef,
     ExportReadSetFilterTypeDef,
@@ -64,10 +67,12 @@ from .type_defs import (
     ListAnnotationImportJobsResponseTypeDef,
     ListAnnotationStoresFilterTypeDef,
     ListAnnotationStoresResponseTypeDef,
+    ListMultipartReadSetUploadsResponseTypeDef,
     ListReadSetActivationJobsResponseTypeDef,
     ListReadSetExportJobsResponseTypeDef,
     ListReadSetImportJobsResponseTypeDef,
     ListReadSetsResponseTypeDef,
+    ListReadSetUploadPartsResponseTypeDef,
     ListReferenceImportJobsResponseTypeDef,
     ListReferencesResponseTypeDef,
     ListReferenceStoresResponseTypeDef,
@@ -82,23 +87,20 @@ from .type_defs import (
     ListWorkflowsResponseTypeDef,
     PaginatorConfigTypeDef,
     ReadSetFilterTypeDef,
+    ReadSetUploadPartListFilterTypeDef,
     ReferenceFilterTypeDef,
     ReferenceStoreFilterTypeDef,
     SequenceStoreFilterTypeDef,
 )
 
-if sys.version_info >= (3, 9):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "ListAnnotationImportJobsPaginator",
     "ListAnnotationStoresPaginator",
+    "ListMultipartReadSetUploadsPaginator",
     "ListReadSetActivationJobsPaginator",
     "ListReadSetExportJobsPaginator",
     "ListReadSetImportJobsPaginator",
+    "ListReadSetUploadPartsPaginator",
     "ListReadSetsPaginator",
     "ListReferenceImportJobsPaginator",
     "ListReferenceStoresPaginator",
@@ -132,8 +134,8 @@ class ListAnnotationImportJobsPaginator(Paginator):
     def paginate(
         self,
         *,
-        filter: ListAnnotationImportJobsFilterTypeDef = ...,
         ids: Sequence[str] = ...,
+        filter: ListAnnotationImportJobsFilterTypeDef = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnnotationImportJobsResponseTypeDef]:
         """
@@ -151,8 +153,8 @@ class ListAnnotationStoresPaginator(Paginator):
     def paginate(
         self,
         *,
-        filter: ListAnnotationStoresFilterTypeDef = ...,
         ids: Sequence[str] = ...,
+        filter: ListAnnotationStoresFilterTypeDef = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnnotationStoresResponseTypeDef]:
         """
@@ -161,6 +163,21 @@ class ListAnnotationStoresPaginator(Paginator):
         """
 
 
+class ListMultipartReadSetUploadsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Paginator.ListMultipartReadSetUploads)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/paginators/#listmultipartreadsetuploadspaginator)
+    """
+
+    def paginate(
+        self, *, sequenceStoreId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListMultipartReadSetUploadsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Paginator.ListMultipartReadSetUploads.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/paginators/#listmultipartreadsetuploadspaginator)
+        """
+
+
 class ListReadSetActivationJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Paginator.ListReadSetActivationJobs)
@@ -218,6 +235,27 @@ class ListReadSetImportJobsPaginator(Paginator):
         """
 
 
+class ListReadSetUploadPartsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Paginator.ListReadSetUploadParts)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/paginators/#listreadsetuploadpartspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        sequenceStoreId: str,
+        uploadId: str,
+        partSource: ReadSetPartSourceType,
+        filter: ReadSetUploadPartListFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListReadSetUploadPartsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Paginator.ListReadSetUploadParts.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_omics/paginators/#listreadsetuploadpartspaginator)
+        """
+
+
 class ListReadSetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Paginator.ListReadSets)
@@ -338,6 +376,7 @@ class ListRunsPaginator(Paginator):
         *,
         name: str = ...,
         runGroupId: str = ...,
+        status: RunStatusType = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRunsResponseTypeDef]:
         """
@@ -373,8 +412,8 @@ class ListVariantImportJobsPaginator(Paginator):
     def paginate(
         self,
         *,
-        filter: ListVariantImportJobsFilterTypeDef = ...,
         ids: Sequence[str] = ...,
+        filter: ListVariantImportJobsFilterTypeDef = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListVariantImportJobsResponseTypeDef]:
         """
@@ -392,8 +431,8 @@ class ListVariantStoresPaginator(Paginator):
     def paginate(
         self,
         *,
-        filter: ListVariantStoresFilterTypeDef = ...,
         ids: Sequence[str] = ...,
+        filter: ListVariantStoresFilterTypeDef = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListVariantStoresResponseTypeDef]:
         """
@@ -411,8 +450,8 @@ class ListWorkflowsPaginator(Paginator):
     def paginate(
         self,
         *,
+        type: WorkflowTypeType = ...,
         name: str = ...,
-        type: Literal["PRIVATE"] = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListWorkflowsResponseTypeDef]:
         """
