@@ -52,6 +52,7 @@ from typing import Sequence
 
 from botocore.waiter import Waiter
 
+from .literals import WorkflowTypeType
 from .type_defs import WaiterConfigTypeDef
 
 if sys.version_info >= (3, 9):
@@ -140,7 +141,7 @@ class ReadSetExportJobCompletedWaiter(Waiter):
     """
 
     def wait(
-        self, *, id: str, sequenceStoreId: str, WaiterConfig: WaiterConfigTypeDef = ...
+        self, *, sequenceStoreId: str, id: str, WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#Omics.Waiter.ReadSetExportJobCompleted.wait)
@@ -291,8 +292,8 @@ class WorkflowActiveWaiter(Waiter):
         self,
         *,
         id: str,
+        type: WorkflowTypeType = ...,
         export: Sequence[Literal["DEFINITION"]] = ...,
-        type: Literal["PRIVATE"] = ...,
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
